==> 0.1.47.tar.gz: lib/network_resources/model/event_info_model.dart <==
import 'package:oowoo_core/network_resources/model/model.dart';

class EventInfoModel {
  late String eventUniqueId;
  late int cardType;
  late int delayValue;
  late UserModel userInfo;
  late ProInfo proInfo;
  late TicketInfoModel ticketInfo;
  PeEventModel? pcEvent;
  PlaceModel? placeInfo;
  late ProServiceModel serviceInfo;
  late ShopInfoModel shopInfo;
  late ShopInvoiceInfoModel shopInvoiceInfo;
  late List<ShopItemModel> itemList;
  LocationModel? userLocation;
  String? utcModifier;
  CarrierInfoModel? carrierInfo;
  SellerMissionModel? salesMissions;
  HomelidoMeeting? homelidoMeeting;

  EventInfoModel({
    required this.eventUniqueId,
    required this.cardType,
    required this.userInfo,
    required this.proInfo,
    required this.ticketInfo,
    required this.serviceInfo,
    required this.shopInfo,
    required this.shopInvoiceInfo,
    required this.itemList,
    this.pcEvent,
    this.homelidoMeeting,
    this.placeInfo,
    this.salesMissions,
    this.utcModifier,
    this.userLocation,
    this.carrierInfo,
  });

  EventInfoModel.fromJson(Map<String, dynamic> json) {
    try {
      eventUniqueId = json['eventUniqueId'] ?? '';
      cardType = json['cardType'] ?? 2;
      utcModifier = json['utcModifier'];
      delayValue = json['delayValue'] ?? 0;
      userInfo = UserModel.fromJson(json['userInfo'] ?? {});
      proInfo = ProInfo.fromJson(json['proInfo'] ?? {});
      ticketInfo = TicketInfoModel.fromJson(json['ticketInfo'] ?? {});
      pcEvent = PeEventModel.fromJson(json['pcEvent'] ?? {});
      placeInfo = json['placeInfo'] == null
          ? null
          : PlaceModel.fromJson(json['placeInfo'] ?? {});
      serviceInfo = ProServiceModel.fromJson(json['serviceInfo'] ?? {});
      shopInfo = ShopInfoModel.fromJson(json['shopInfo'] ?? {});
      shopInvoiceInfo =
          ShopInvoiceInfoModel.fromJson(json['shopInvoiceInfo'] ?? {});

      if (json['userLocation'] != null) {
        userLocation = LocationModel.fromJson(json['userLocation']);
      }
      if (json['homelidoMeeting'] != null) {
        homelidoMeeting = HomelidoMeeting.fromJson(json['homelidoMeeting']);
      }
      if (json['carrierInfo'] != null) {
        carrierInfo = CarrierInfoModel.fromJson(json['carrierInfo']);
      }
      if (json['salesMissions'] != null) {
        salesMissions = SellerMissionModel.fromJson(json['salesMissions']);
      }
      if (json['itemList'] != null) {
        itemList = json['itemList']
            .map<ShopItemModel>((e) => ShopItemModel.fromJson(e))
            .toList();
      } else {
        itemList = [];
      }
    } catch (e) {
      print('EventInfoModel.fromJson: $e');
    }
  }

  Map<String, dynamic> toJson() {
    final Map<String, dynamic> data = new Map<String, dynamic>();
    data['eventUniqueId'] = this.eventUniqueId;
    data['cardType'] = this.cardType;
    data['utcModifier'] = this.utcModifier;
    data['delayValue'] = this.delayValue;
    data['userInfo'] = this.userInfo.toJson();
    data['proInfo'] = this.proInfo.toJson();
    data['ticketInfo'] = this.ticketInfo.toJson();
    data['pcEvent'] = this.pcEvent?.toJson();
    data['placeInfo'] = this.placeInfo?.toJson();
    data['serviceInfo'] = this.serviceInfo.toJson();
    data['shopInfo'] = this.shopInfo.toJson();
    data['shopInvoiceInfo'] = this.shopInvoiceInfo.toJson();
    data['userLocation'] = this.userLocation?.toJson();
    data['homelidoMeeting'] = this.homelidoMeeting?.toJson();
    data['carrierInfo'] = this.carrierInfo?.toJson();
    data['salesMissions'] = this.salesMissions?.toJson();
    data['itemList'] = this.itemList.map((e) => e.toJson()).toList();
    return data;
  }
}

class ShopInfoModel {
  late String shopDisplayName;
  late String colorCode;
  late String shopUniqueId;
  late String shopPicture;

  ShopInfoModel({
    required this.shopDisplayName,
    required this.colorCode,
    required this.shopUniqueId,
    required this.shopPicture,
  });

  ShopInfoModel.fromJson(Map<String, dynamic> json) {
    shopDisplayName = json['shopDisplayName'] ?? 'PPRRTX4KC';
    colorCode = json['colorCode'] ?? '';
    shopUniqueId = json['shopUniqueId'] ?? '';
    shopPicture = json['shopPicture'] ?? '';
  }
  Map<String, dynamic> toJson() {
    final Map<String, dynamic> data = new Map<String, dynamic>();
    data['shopDisplayName'] = this.shopDisplayName;
    data['colorCode'] = this.colorCode;
    data['shopUniqueId'] = this.shopUniqueId;
    data['shopPicture'] = this.shopPicture;
    return data;
  }
}

class ShopInvoiceInfoModel {
  String? itemTitle;
  String? colorCode;
  String? shopInvoiceUniqueId;
  String? currency;
  String? pictureUrl;
  int? proId;
  double? price;
  String? qr;
  int? commissionId;
  int? purchasedAt;
  int? paymentStatus;

  ShopInvoiceInfoModel({
    this.proId,
    this.currency,
    this.colorCode,
    this.shopInvoiceUniqueId,
    this.pictureUrl,
    this.commissionId,
    this.itemTitle,
    this.price,
    this.qr,
    this.purchasedAt,
    this.paymentStatus,
  });

  ShopInvoiceInfoModel.fromJson(Map<String, dynamic> json) {
    pictureUrl = json['pictureUrl'] ?? '';
    colorCode = json['colorCode'] ?? '';
    shopInvoiceUniqueId = json['shopInvoiceUniqueId'] ?? '';
    currency = json['currency'] ?? '';
    proId = json['proId'] ?? 0;
    price = json['price'] ?? 0.0;
    commissionId = json['commissionId'] ?? 0;
    qr = json['qr'];
    purchasedAt = json['purchasedAt'] ?? 0;
    paymentStatus = json['paymentStatus'];
  }
  Map<String, dynamic> toJson() {
    final Map<String, dynamic> data = new Map<String, dynamic>();
    data['pictureUrl'] = this.pictureUrl;
    data['colorCode'] = this.colorCode;
    data['shopInvoiceUniqueId'] = this.shopInvoiceUniqueId;
    data['currency'] = this.currency;
    data['proId'] = this.proId;
    data['price'] = this.price;
    data['commissionId'] = this.commissionId;
    data['qr'] = this.qr;
    data['purchasedAt'] = this.purchasedAt;
    data['paymentStatus'] = this.paymentStatus;
    return data;
  }
}

class ShopItemModel {
  String? title;
  String? colorCode;
  String? description;
  String? currency;
  String? pictureUrl;
  double? price;
  int? commissionId;

  ShopItemModel(
      {this.currency,
      this.colorCode,
      this.description,
      this.pictureUrl,
      this.commissionId,
      this.title,
      this.price});

  ShopItemModel.fromJson(Map<String, dynamic> json) {
    pictureUrl = json['pictureUrl'] ?? '';
    title = json['title'] ?? '';
    colorCode = json['colorCode'] ?? '';
    description = json['description'] ?? '';
    currency = json['currency'] ?? '';
    price = json['price'] ?? 0.0;
    commissionId = json['commissionId'] ?? 0;
  }
  Map<String, dynamic> toJson() {
    final Map<String, dynamic> data = new Map<String, dynamic>();
    data['pictureUrl'] = this.pictureUrl;
    data['colorCode'] = this.colorCode;
    data['title'] = this.title;
    data['currency'] = this.currency;
    data['description'] = this.description;
    data['price'] = this.price;
    data['commissionId'] = this.commissionId;
    return data;
  }
}

class CarrierInfoModel {
  String? displayName;
  String? firebaseId;
  String? phone;
  String? id;
  String? thumbnail;
  int? allowChat;

  CarrierInfoModel({this.displayName, this.firebaseId, this.phone, this.id});

  CarrierInfoModel.fromJson(Map<String, dynamic> json) {
    thumbnail = json['carrierThumbnail'] ?? '/thumbnails/users/default.jpg';
    phone = json['carrierPhoneNumber'] ?? '';
    displayName = json['carrierDisplayName'] ?? '';
    firebaseId = json['carrierFirebaseId'] ?? '';
    allowChat = json['carrierAllowChat'] ?? 1;
  }
  Map<String, dynamic> toJson() {
    final Map<String, dynamic> data = new Map<String, dynamic>();
    data['carrierThumbnail'] = this.thumbnail;
    data['carrierPhoneNumber'] = this.phone;
    data['carrierDisplayName'] = this.displayName;
    data['carrierFirebaseId'] = this.firebaseId;
    data['carrierAllowChat'] = this.allowChat;
    return data;
  }
}

==> 0.2.9.tar.gz: lib/network_resources/model/event_info_model.dart <==
import 'package:oowoo_core/network_resources/model/model.dart';
import 'package:oowoo_core/oowoo_core.dart';

class EventInfoModel {
  late String eventUniqueId;
  late int cardType;
  late int delayValue;
  late UserModel userInfo;
  late ProInfo proInfo;
  late TicketInfoModel ticketInfo;
  PeEventModel? pcEvent;
  PlaceModel? placeInfo;
  late ProServiceModel serviceInfo;
  late ShopInfoModel shopInfo;
  late ShopInvoiceInfoModel shopInvoiceInfo;
  late List<ShopItemModel> itemList;
  LocationModel? userLocation;
  String? utcModifier;
  CarrierInfoModel? carrierInfo;
  SellerMissionModel? salesMissions;
  HomelidoMeeting? homelidoMeeting;

  EventInfoModel({
    required this.eventUniqueId,
    required this.cardType,
    required this.userInfo,
    required this.proInfo,
    required this.ticketInfo,
    required this.serviceInfo,
    required this.shopInfo,
    required this.shopInvoiceInfo,
    required this.itemList,
    this.pcEvent,
    this.homelidoMeeting,
    this.placeInfo,
    this.salesMissions,
    this.utcModifier,
    this.userLocation,
    this.carrierInfo,
  });

  EventInfoModel.fromJson(Map<String, dynamic> json) {
    try {
      eventUniqueId = json['eventUniqueId'] ?? '';
      cardType = json['cardType'] ?? 2;
      utcModifier = json['utcModifier'];
      delayValue = json['delayValue'] ?? 0;
      userInfo = UserModel.fromJson(json['userInfo'] ?? {});
      proInfo = ProInfo.fromJson(json['proInfo'] ?? {});
      ticketInfo = TicketInfoModel.fromJson(json['ticketInfo'] ?? {});
      pcEvent = PeEventModel.fromJson(json['pcEvent'] ?? {});
      placeInfo = json['placeInfo'] == null
          ? null
          : PlaceModel.fromJson(json['placeInfo'] ?? {});
      serviceInfo = ProServiceModel.fromJson(json['serviceInfo'] ?? {});
      shopInfo = ShopInfoModel.fromJson(json['shopInfo'] ?? {});
      shopInvoiceInfo =
          ShopInvoiceInfoModel.fromJson(json['shopInvoiceInfo'] ?? {});

      if (json['userLocation'] != null) {
        userLocation = LocationModel.fromJson(json['userLocation']);
      }
      if (json['homelidoMeeting'] != null) {
        homelidoMeeting = HomelidoMeeting.fromJson(json['homelidoMeeting']);
      }
      if (json['carrierInfo'] != null) {
        carrierInfo = CarrierInfoModel.fromJson(json['carrierInfo']);
      }
      if (json['salesMissions'] != null) {
        salesMissions = SellerMissionModel.fromJson(json['salesMissions']);
      }
      if (json['itemList'] != null) {
        itemList = json['itemList']
            .map<ShopItemModel>((e) => ShopItemModel.fromJson(e))
            .toList();
      } else {
        itemList = [];
      }
    } catch (e) {
      appDebugPrint('EventInfoModel.fromJson: $e');
    }
  }

  Map<String, dynamic> toJson() {
    final Map<String, dynamic> data = new Map<String, dynamic>();
    data['eventUniqueId'] = this.eventUniqueId;
    data['cardType'] = this.cardType;
    data['utcModifier'] = this.utcModifier;
    data['delayValue'] = this.delayValue;
    data['userInfo'] = this.userInfo.toJson();
    data['proInfo'] = this.proInfo.toJson();
    data['ticketInfo'] = this.ticketInfo.toJson();
    data['pcEvent'] = this.pcEvent?.toJson();
    data['placeInfo'] = this.placeInfo?.toJson();
    data['serviceInfo'] = this.serviceInfo.toJson();
    data['shopInfo'] = this.shopInfo.toJson();
    data['shopInvoiceInfo'] = this.shopInvoiceInfo.toJson();
    data['userLocation'] = this.userLocation?.toJson();
    data['homelidoMeeting'] = this.homelidoMeeting?.toJson();
    data['carrierInfo'] = this.carrierInfo?.toJson();
    data['salesMissions'] = this.salesMissions?.toJson();
    data['itemList'] = this.itemList.map((e) => e.toJson()).toList();
    return data;
  }
}

class ShopInfoModel {
  late String shopDisplayName;
  late String colorCode;
  late String shopUniqueId;
  late String shopPicture;

  ShopInfoModel({
    required this.shopDisplayName,
    required this.colorCode,
    required this.shopUniqueId,
    required this.shopPicture,
  });

  ShopInfoModel.fromJson(Map<String, dynamic> json) {
    shopDisplayName = json['shopDisplayName'] ?? 'PPRRTX4KC';
    colorCode = json['colorCode'] ?? '';
    shopUniqueId = json['shopUniqueId'] ?? '';
    shopPicture = json['shopPicture'] ?? '';
  }
  Map<String, dynamic> toJson() {
    final Map<String, dynamic> data = new Map<String, dynamic>();
    data['shopDisplayName'] = this.shopDisplayName;
    data['colorCode'] = this.colorCode;
    data['shopUniqueId'] = this.shopUniqueId;
    data['shopPicture'] = this.shopPicture;
    return data;
  }
}

class ShopInvoiceInfoModel {
  String? itemTitle;
  String? colorCode;
  String? shopInvoiceUniqueId;
  String? currency;
  String? pictureUrl;
  int? proId;
  double? price;
  String? qr;
  int? commissionId;
  int? purchasedAt;
  int? paymentStatus;

  ShopInvoiceInfoModel({
    this.proId,
    this.currency,
    this.colorCode,
    this.shopInvoiceUniqueId,
    this.pictureUrl,
    this.commissionId,
    this.itemTitle,
    this.price,
    this.qr,
    this.purchasedAt,
    this.paymentStatus,
  });

  ShopInvoiceInfoModel.fromJson(Map<String, dynamic> json) {
    pictureUrl = json['pictureUrl'] ?? '';
    colorCode = json['colorCode'] ?? '';
    shopInvoiceUniqueId = json['shopInvoiceUniqueId'] ?? '';
    currency = json['currency'] ?? '';
    proId = json['proId'] ?? 0;
    price = json['price'] ?? 0.0;
    commissionId = json['commissionId'] ?? 0;
    qr = json['qr'];
    purchasedAt = json['purchasedAt'] ?? 0;
    paymentStatus = json['paymentStatus'];
  }
  Map<String, dynamic> toJson() {
    final Map<String, dynamic> data = new Map<String, dynamic>();
    data['pictureUrl'] = this.pictureUrl;
    data['colorCode'] = this.colorCode;
    data['shopInvoiceUniqueId'] = this.shopInvoiceUniqueId;
    data['currency'] = this.currency;
    data['proId'] = this.proId;
    data['price'] = this.price;
    data['commissionId'] = this.commissionId;
    data['qr'] = this.qr;
    data['purchasedAt'] = this.purchasedAt;
    data['paymentStatus'] = this.paymentStatus;
    return data;
  }
}

class ShopItemModel {
  String? title;
  String? colorCode;
  String? description;
  String? currency;
  String? pictureUrl;
  double? price;
  int? commissionId;

  ShopItemModel(
      {this.currency,
      this.colorCode,
      this.description,
      this.pictureUrl,
      this.commissionId,
      this.title,
      this.price});

  ShopItemModel.fromJson(Map<String, dynamic> json) {
    pictureUrl = json['pictureUrl'] ?? '';
    title = json['title'] ?? '';
    colorCode = json['colorCode'] ?? '';
    description = json['description'] ?? '';
    currency = json['currency'] ?? '';
    price = json['price'] ?? 0.0;
    commissionId = json['commissionId'] ?? 0;
  }
  Map<String, dynamic> toJson() {
    final Map<String, dynamic> data = new Map<String, dynamic>();
    data['pictureUrl'] = this.pictureUrl;
    data['colorCode'] = this.colorCode;
    data['title'] = this.title;
    data['currency'] = this.currency;
    data['description'] = this.description;
    data['price'] = this.price;
    data['commissionId'] = this.commissionId;
    return data;
  }
}

class CarrierInfoModel {
  String? displayName;
  String? firebaseId;
  String? phone;
  String? id;
  String? thumbnail;
  int? allowChat;

  CarrierInfoModel({this.displayName, this.firebaseId, this.phone, this.id});

  CarrierInfoModel.fromJson(Map<String, dynamic> json) {
    thumbnail = json['carrierThumbnail'] ?? '/thumbnails/users/default.jpg';
    phone = json['carrierPhoneNumber'] ?? '';
    displayName = json['carrierDisplayName'] ?? '';
    firebaseId = json['carrierFirebaseId'] ?? '';
    allowChat = json['carrierAllowChat'] ?? 1;
  }
  Map<String, dynamic> toJson() {
    final Map<String, dynamic> data = new Map<String, dynamic>();
    data['carrierThumbnail'] = this.thumbnail;
    data['carrierPhoneNumber'] = this.phone;
    data['carrierDisplayName'] = this.displayName;
    data['carrierFirebaseId'] = this.firebaseId;
    data['carrierAllowChat'] = this.allowChat;
    return data;
  }
}
